==> openx-2.5.69-beta.tar.bz2: openx-2.5.69-beta/lib/max/language/tr/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 21310 2008-06-12 11:12:19Z david.keen@openx.org $
*/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Uzak Yardım";
$GLOBALS['strInvocationJS']			= "Javascript için uzak yardım";
$GLOBALS['strInvocationIframes']		= "Frameler için uzak yardım";
$GLOBALS['strInvocationXmlRpc']			= "XML-RPC kullanan uzak yardım";
$GLOBALS['strInvocationCombined']		= "Birleştirilmiş uzak yardım";
$GLOBALS['strInvocationPopUp']			= "Pop-up";
$GLOBALS['strInvocationAdLayer']		= "Yüzen DHTML";
$GLOBALS['strInvocationLocal']			= "Yerel kip";


// Other
$GLOBALS['strCopyToClipboard']			= "Panoya Kopyala";


// Measures
$GLOBALS['strAbbrPixels']			= "px";
$GLOBALS['strAbbrSeconds']			= "sec";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Banner seçimi";
$GLOBALS['strInvocationClientID']		= "Reklamcılar veya Kampanyalar";
$GLOBALS['strInvocationTarget']			= "Hedef frame";
$GLOBALS['strInvocationSource']			= "Kaynak";
$GLOBALS['strInvocationWithText']		= "Banner altında yazı göster";
$GLOBALS['strInvocationDontShowAgain']		= "Aynı sayfada bannerı tekrar gösterme";
$GLOBALS['strInvocationTemplate'] 		= "Şablon içerisinde kullanım için Bannerı bir değişken içinde sakla.";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Refresh sonra";
$GLOBALS['strIframeResizeToBanner']		= "iframe banner ölçülerine göre düzenle";
$GLOBALS['strIframeMakeTransparent']		= "iframe i transparan yap";
$GLOBALS['strIframeIncludeNetscape4']		= "Netscape 4 uyumlu ilayer kullan";


// PopUp
$GLOBALS['strPopUpStyle']			= "Pop-up tipi";
$GLOBALS['strPopUpStylePopUp']			= "Pop-up";
$GLOBALS['strPopUpStylePopUnder']		= "Pop-under";
$GLOBALS['strPopUpCreateInstance']		= "Instance when the pop-up is created";
$GLOBALS['strPopUpImmediately']			= "Hemen";
$GLOBALS['strPopUpOnClose']			= "Sayfa kapandığında";
$GLOBALS['strPopUpAfterSec']			= "Sonra";
$GLOBALS['strAutoCloseAfter']			= "Süre sonra otomatik kapat";
$GLOBALS['strPopUpTop']				= "Başlangıç konumu (üst)";
$GLOBALS['strPopUpLeft']			= "Başlangıç konumu (sol)";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Sunucu Dili";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "Stil";

$GLOBALS['strAlignment']			= "Hiza";
$GLOBALS['strHAlignment']			= "Yatay hiza";
$GLOBALS['strLeft']				= "Left";
$GLOBALS['strCenter']				= "Center";
$GLOBALS['strRight']				= "Right";

$GLOBALS['strVAlignment']			= "Dikey hiza";
$GLOBALS['strTop']				= "Top";
$GLOBALS['strMiddle']				= "Middle";
$GLOBALS['strBottom']				= "Bottom";

$GLOBALS['strAutoCollapseAfter']		= "Otomatik olarak aşağı at";
$GLOBALS['strCloseText']			= "Kapat Yazısı";
$GLOBALS['strClose']				= "[Kapat]";
$GLOBALS['strBannerPadding']			= "Banner dolgusu";

$GLOBALS['strHShift']				= "Yatay Değiştir";
$GLOBALS['strVShift']				= "Dikey değiştir";

$GLOBALS['strShowCloseButton']			= "Kapat Butonunu Göster";
$GLOBALS['strBackgroundColor']			= "Zemin Rengi";
$GLOBALS['strBorderColor']			= "Çerçeve Rengi";

$GLOBALS['strDirection']			= "Yön";
$GLOBALS['strLeftToRight']			= "Left to right";
$GLOBALS['strRightToLeft']			= "Right to left";
$GLOBALS['strLooping']				= "Döngü";
$GLOBALS['strAlwaysActive']			= "Herzaman Aktif";
$GLOBALS['strSpeed']				= "Hız";
$GLOBALS['strPause']				= "Durdurulmuş";
$GLOBALS['strLimited']				= "sınırlanmış";
$GLOBALS['strLeftMargin']			= "Left margin";
$GLOBALS['strRightMargin']			= "Right margin";
$GLOBALS['strTransparentBackground']		= "Transparan zemin";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Basit",
	'cursor'		=> "Gelişigüzel",
	'floater'		=> "Yüzen"
);

?>

==> openx-2.7.27-beta.tar.bz2: openx-2.7.27-beta/lib/max/language/tr/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.7                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 29689 2008-12-03 16:30:29Z andrew.hill $
*/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Uzak Yardım";
$GLOBALS['strInvocationJS']			= "Javascript için uzak yardım";
$GLOBALS['strInvocationIframes']		= "Frameler için uzak yardım";
$GLOBALS['strInvocationXmlRpc']			= "XML-RPC kullanan uzak yardım";
$GLOBALS['strInvocationCombined']		= "Birleştirilmiş uzak yardım";
$GLOBALS['strInvocationPopUp']			= "Pop-up";
$GLOBALS['strInvocationAdLayer']		= "Yüzen DHTML";
$GLOBALS['strInvocationLocal']			= "Yerel kip";


// Other
$GLOBALS['strCopyToClipboard']			= "Panoya kopyala";


// Measures
$GLOBALS['strAbbrPixels']			= "px";
$GLOBALS['strAbbrSeconds']			= "sec";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Banner seçimi";
$GLOBALS['strInvocationClientID']		= "Reklamcılar veya Kampanyalar";
$GLOBALS['strInvocationTarget']			= "Hedef çerçeve";
$GLOBALS['strInvocationSource']			= "Kaynak";
$GLOBALS['strInvocationWithText']		= "Banner altında yazı göster";
$GLOBALS['strInvocationDontShowAgain']		= "Aynı sayfada bannerı tekrar gösterme";
$GLOBALS['strInvocationTemplate'] 		= "Şablon içerisinde kullanım için bannerı bir değişken içinde sakla.";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Şu zaman sonunda yenile";
$GLOBALS['strIframeResizeToBanner']		= "Çerçeveyi banner ölçüsüne göre yeniden boyutlandır";
$GLOBALS['strIframeMakeTransparent']		= "Çerçeveyi şeffaf yap";
$GLOBALS['strIframeIncludeNetscape4']		= "Netscape 4 uyumlu ilayer kullan";


// PopUp
$GLOBALS['strPopUpStyle']			= "Pop-up tipi";
$GLOBALS['strPopUpStylePopUp']			= "Pop-up";
$GLOBALS['strPopUpStylePopUnder']		= "Pop-under";
$GLOBALS['strPopUpCreateInstance']		= "Instance when the pop-up is created";
$GLOBALS['strPopUpImmediately']			= "Hemen";
$GLOBALS['strPopUpOnClose']			= "Sayfa kapandığında";
$GLOBALS['strPopUpAfterSec']			= "Sonra";
$GLOBALS['strAutoCloseAfter']			= "Süre sonra otomatik kapat";
$GLOBALS['strPopUpTop']				= "Başlangıç konumu (üst)";
$GLOBALS['strPopUpLeft']			= "Başlangıç konumu (sol)";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Sunucu Dili";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "Stil";

$GLOBALS['strAlignment']			= "Hiza";
$GLOBALS['strHAlignment']			= "Yatay hiza";
$GLOBALS['strLeft']				= "Left";
$GLOBALS['strCenter']				= "Center";
$GLOBALS['strRight']				= "Right";

$GLOBALS['strVAlignment']			= "Dikey hiza";
$GLOBALS['strTop']				= "Top";
$GLOBALS['strMiddle']				= "Middle";
$GLOBALS['strBottom']				= "Bottom";

$GLOBALS['strAutoCollapseAfter']		= "Otomatik olarak aşağı at";
$GLOBALS['strCloseText']			= "Kapat Yazısı";
$GLOBALS['strClose']				= "[Kapat]";
$GLOBALS['strBannerPadding']			= "Banner dolgusu";

$GLOBALS['strHShift']				= "Yatay Değiştir";
$GLOBALS['strVShift']				= "Dikey değiştir";

$GLOBALS['strShowCloseButton']			= "Kapat Butonunu Göster";
$GLOBALS['strBackgroundColor']			= "Zemin Rengi";
$GLOBALS['strBorderColor']			= "Çerçeve Rengi";

$GLOBALS['strDirection']			= "Yön";
$GLOBALS['strLeftToRight']			= "Left to right";
$GLOBALS['strRightToLeft']			= "Right to left";
$GLOBALS['strLooping']				= "Döngü";
$GLOBALS['strAlwaysActive']			= "Herzaman Aktif";
$GLOBALS['strSpeed']				= "Hız";
$GLOBALS['strPause']				= "Duraklat";
$GLOBALS['strLimited']				= "sınırlanmış";
$GLOBALS['strLeftMargin']			= "Left margin";
$GLOBALS['strRightMargin']			= "Right margin";
$GLOBALS['strTransparentBackground']		= "Transparan zemin";


$GLOBALS['strAdLayerStyleName']['geocities'] = "GeocitiesBasitGelişigüzelYüzen";
$GLOBALS['strAdLayerStyleName']['simple'] = "Basit";
$GLOBALS['strAdLayerStyleName']['cursor'] = "Gelişigüzel";
$GLOBALS['strAdLayerStyleName']['floater'] = "Yüzen";




// Note: New translations not found in original lang files but found in CSV
$GLOBALS['strInvocationCampaignID'] = "Kampanya";
$GLOBALS['strCopy'] = "kopyala";
$GLOBALS['strInvocationDontShowAgainCampaign'] = "Aynı sayfada aynı kampanyadan başka bir banner gösterme";
$GLOBALS['strInvocationBannerID'] = "Banner ID";
$GLOBALS['strInvocationComments'] = "Yorumlarla birlikte";
$GLOBALS['strChooseTypeOfInvocation'] = "Lütfen banner çağırma tipini seçiniz";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "Lütfen banner çağırma tipini seçiniz";
?>
